@@ -73,8 +73,7 @@ GList * rtcom_el_plugin_eventtypes(void)
         gchar * name;
         gchar * desc;
     } types[] = {
-        {"RTCOM_EL_EVENTTYPE_SMS_INBOUND", "Inbound SMS"},
-        {"RTCOM_EL_EVENTTYPE_SMS_OUTBOUND", "Outbound SMS"},
+        {"RTCOM_EL_EVENTTYPE_SMS_MESSAGE", "SMS message"},
         {NULL, NULL}
     };
 
@@ -153,10 +152,11 @@ gboolean rtcom_el_plugin_get_value(
     }
     else if(!strcmp(item, "icon-name"))
     {
-        GValue local_uid = {0}, group_uid = {0};
+        GValue local_uid = {0}, group_uid = {0}, out_gval = {0};
         gint total_events = 0;
         gint unread_events = 0;
         gint group_flags = 0;
+        gboolean outgoing = FALSE;
 
         RTComEl * el;
         RTComElQuery * query;
@@ -168,6 +168,9 @@ gboolean rtcom_el_plugin_get_value(
         g_object_get(query, "group-by", &group_by, NULL);
 
         rtcom_el_iter_get_raw(it, "local-uid", &local_uid);
+        rtcom_el_iter_get_raw(it, "outgoing", &out_gval);
+        outgoing = g_value_get_boolean(&out_gval);
+        g_value_unset(&out_gval);
 
         if(group_by == RTCOM_EL_QUERY_GROUP_BY_GROUP)
         {
@@ -197,13 +200,14 @@ gboolean rtcom_el_plugin_get_value(
              * exclusive.
              */
 
-            if(group_flags & RTCOM_EL_FLAG_SMS_PERMANENT_ERROR)
+            if(group_flags & (RTCOM_EL_FLAG_SMS_PERMANENT_ERROR |
+                  RTCOM_EL_FLAG_SMS_TEMPORARY_ERROR))
                 g_value_set_string(value, "chat_failed_sms");
             else if(group_flags & RTCOM_EL_FLAG_SMS_PENDING)
                 g_value_set_string(value, "chat_pending_sms");
             else if(unread_events)
                 g_value_set_string(value, "chat_unread_sms");
-            else if(strcmp(type, "RTCOM_EL_EVENTTYPE_SMS_OUTBOUND") == 0)
+            else if(outgoing)
                 g_value_set_string(value, "chat_replied_sms");
             else
                 g_value_set_string(value, "general_sms");
@@ -216,18 +220,16 @@ gboolean rtcom_el_plugin_get_value(
             rtcom_el_iter_get_raw(it, "flags", &flags);
             rtcom_el_iter_get_raw(it, "is-read", &is_read);
 
-            g_warning("%s: here: %s, %s", G_STRFUNC, G_VALUE_TYPE_NAME(&flags), G_VALUE_TYPE_NAME(&is_read));
             if(g_value_get_int(&flags) & RTCOM_EL_FLAG_SMS_PERMANENT_ERROR)
                 g_value_set_string(value, "chat_failed_sms");
             else if(g_value_get_int(&flags) & RTCOM_EL_FLAG_SMS_PENDING)
                 g_value_set_string(value, "chat_pending_sms");
             else if (g_value_get_boolean(&is_read) == FALSE)
                 g_value_set_string(value, "chat_unread_sms");
-            else if(strcmp(type, "RTCOM_EL_EVENTTYPE_SMS_OUTBOUND") == 0)
+            else if(outgoing)
                 g_value_set_string(value, "chat_replied_sms");
             else
                 g_value_set_string(value, "general_sms");
-            g_warning("%s: here ends", G_STRFUNC);
 
             g_value_unset(&flags);
             g_value_unset(&is_read);
